@@ -1,7 +1,11 @@
 #!/usr/bin/env bash
 
+NC='\033[0m'
+RED='\033[0;31m'
+YELLOW='\033[0;33m'
+
 if [[ -z "$1" ]]; then
-  echo "You must include an SVG file to convert!"
+  echo -e "${RED}You must include an SVG file to convert!${NC}"
   exit 1
 fi
 
@@ -10,6 +14,11 @@ if [[ -z "outfile" ]]; then
   outfile="logo.ico"
 fi
 
+if ! command -v "inkscape" &> /dev/null; then
+  echo -e "${YELLOW}Could not find inkscape; $outfile not built!${NC}"
+  exit 0
+fi
+
 echo "Generating $outfile from $1..."
 size_list=(16 24 32 48 64 128 256)
 for size in ${size_list[@]}; do
