@@ -18,15 +18,19 @@
 
 #include "AutoTypeMatch.h"
 
+#include <utility>
+
 AutoTypeMatch::AutoTypeMatch()
-  : entry(nullptr),
-    sequence()
-{}
+    : entry(nullptr)
+    , sequence()
+{
+}
 
 AutoTypeMatch::AutoTypeMatch(Entry* entry, QString sequence)
-  : entry(entry),
-    sequence(sequence)
-{}
+    : entry(entry)
+    , sequence(std::move(sequence))
+{
+}
 
 bool AutoTypeMatch::operator==(const AutoTypeMatch& other) const
 {
