@@ -60,7 +60,7 @@ void Merger::resetForcedMergeMode()
     m_mode = Group::Default;
 }
 
-bool Merger::merge()
+QStringList Merger::merge()
 {
     // Order of merge steps is important - it is possible that we
     // create some items before deleting them afterwards
@@ -74,9 +74,8 @@ bool Merger::merge()
     // At this point we have a list of changes we may want to show the user
     if (!changes.isEmpty()) {
         m_context.m_targetDb->markAsModified();
-        return true;
     }
-    return false;
+    return changes;
 }
 
 Merger::ChangeList Merger::mergeGroup(const MergeContext& context)
@@ -613,27 +612,28 @@ Merger::ChangeList Merger::mergeMetadata(const MergeContext& context)
     auto* sourceMetadata = context.m_sourceDb->metadata();
     auto* targetMetadata = context.m_targetDb->metadata();
 
-    const auto keys = sourceMetadata->customIcons().keys();
-    for (QUuid customIconId : keys) {
-        if (!targetMetadata->containsCustomIcon(customIconId)) {
-            QImage customIcon = sourceMetadata->customIcon(customIconId);
-            targetMetadata->addCustomIcon(customIconId, customIcon);
-            changes << tr("Adding missing icon %1").arg(QString::fromLatin1(customIconId.toRfc4122().toHex()));
+    for (const auto& iconUuid : sourceMetadata->customIconsOrder()) {
+        if (!targetMetadata->hasCustomIcon(iconUuid)) {
+            QImage customIcon = sourceMetadata->customIcon(iconUuid);
+            targetMetadata->addCustomIcon(iconUuid, customIcon);
+            changes << tr("Adding missing icon %1").arg(QString::fromLatin1(iconUuid.toRfc4122().toHex()));
         }
     }
 
     // Merge Custom Data if source is newer
-    const auto targetCustomDataModificationTime = sourceMetadata->customData()->getLastModified();
-    const auto sourceCustomDataModificationTime = targetMetadata->customData()->getLastModified();
-    if (!targetMetadata->customData()->contains(CustomData::LastModified) ||
-        (targetCustomDataModificationTime.isValid() && sourceCustomDataModificationTime.isValid() && 
-         targetCustomDataModificationTime > sourceCustomDataModificationTime)) {
+    const auto targetCustomDataModificationTime = targetMetadata->customData()->getLastModified();
+    const auto sourceCustomDataModificationTime = sourceMetadata->customData()->getLastModified();
+    if (!targetMetadata->customData()->contains(CustomData::LastModified)
+        || (targetCustomDataModificationTime.isValid() && sourceCustomDataModificationTime.isValid()
+            && targetCustomDataModificationTime < sourceCustomDataModificationTime)) {
         const auto sourceCustomDataKeys = sourceMetadata->customData()->keys();
         const auto targetCustomDataKeys = targetMetadata->customData()->keys();
 
         // Check missing keys from source. Remove those from target
         for (const auto& key : targetCustomDataKeys) {
-            if (!sourceMetadata->customData()->contains(key)) {
+            // Do not remove protected custom data
+            if (!sourceMetadata->customData()->contains(key)
+                && !sourceMetadata->customData()->isProtectedCustomData(key)) {
                 auto value = targetMetadata->customData()->value(key);
                 targetMetadata->customData()->remove(key);
                 changes << tr("Removed custom data %1 [%2]").arg(key, value);
@@ -642,9 +642,18 @@ Merger::ChangeList Merger::mergeMetadata(const MergeContext& context)
 
         // Transfer new/existing keys
         for (const auto& key : sourceCustomDataKeys) {
-            auto value = sourceMetadata->customData()->value(key);
-            targetMetadata->customData()->set(key, value);
-            changes << tr("Adding custom data %1 [%2]").arg(key, value);
+            // Don't merge this meta field, it is updated automatically.
+            if (key == CustomData::LastModified) {
+                continue;
+            }
+
+            auto sourceValue = sourceMetadata->customData()->value(key);
+            auto targetValue = targetMetadata->customData()->value(key);
+            // Merge only if the values are not the same.
+            if (sourceValue != targetValue) {
+                targetMetadata->customData()->set(key, sourceValue);
+                changes << tr("Adding custom data %1 [%2]").arg(key, sourceValue);
+            }
         }
     }
 
