@@ -53,15 +53,15 @@ bool Kdbx4Writer::writeDatabase(QIODevice* device, Database* db)
     QByteArray endOfHeader = "\r\n\r\n";
 
     if (!db->setKey(db->key(), false, true)) {
-        raiseError(tr("Unable to calculate master key"));
+        raiseError(tr("Unable to calculate database key: %1").arg(db->keyError()));
         return false;
     }
 
-    // generate transformed master key
+    // generate transformed database key
     CryptoHash hash(CryptoHash::Sha256);
     hash.addData(masterSeed);
-    Q_ASSERT(!db->transformedMasterKey().isEmpty());
-    hash.addData(db->transformedMasterKey());
+    Q_ASSERT(!db->transformedDatabaseKey().isEmpty());
+    hash.addData(db->transformedDatabaseKey());
     QByteArray finalKey = hash.result();
 
     // write header
@@ -70,7 +70,7 @@ bool Kdbx4Writer::writeDatabase(QIODevice* device, Database* db)
         QBuffer header;
         header.open(QIODevice::WriteOnly);
 
-        writeMagicNumbers(&header, KeePass2::SIGNATURE_1, KeePass2::SIGNATURE_2, KeePass2::FILE_VERSION_4);
+        writeMagicNumbers(&header, KeePass2::SIGNATURE_1, KeePass2::SIGNATURE_2, formatVersion());
 
         CHECK_RETURN_FALSE(
             writeHeaderField<quint32>(&header, KeePass2::HeaderFieldID::CipherID, db->cipher().toRfc4122()));
@@ -109,7 +109,7 @@ bool Kdbx4Writer::writeDatabase(QIODevice* device, Database* db)
     QByteArray headerHash = CryptoHash::hash(headerData, CryptoHash::Sha256);
 
     // write HMAC-authenticated cipher stream
-    QByteArray hmacKey = KeePass2::hmacKey(masterSeed, db->transformedMasterKey());
+    QByteArray hmacKey = KeePass2::hmacKey(masterSeed, db->transformedDatabaseKey());
     QByteArray headerHmac =
         CryptoHash::hmac(headerData, HmacBlockStream::getHmacKey(UINT64_MAX, hmacKey), CryptoHash::Sha256);
     CHECK_RETURN_FALSE(writeData(device, headerHash));
@@ -171,7 +171,7 @@ bool Kdbx4Writer::writeDatabase(QIODevice* device, Database* db)
         return false;
     }
 
-    KdbxXmlWriter xmlWriter(KeePass2::FILE_VERSION_4);
+    KdbxXmlWriter xmlWriter(formatVersion());
     xmlWriter.writeDatabase(outputDevice, db, &randomStream, headerHash);
 
     // Explicitly close/reset streams so they are flushed and we can detect
@@ -311,3 +311,8 @@ bool Kdbx4Writer::serializeVariantMap(const QVariantMap& map, QByteArray& output
     CHECK_RETURN_FALSE(buf.write(endBytes) == 1);
     return true;
 }
+
+quint32 Kdbx4Writer::formatVersion()
+{
+    return KeePass2::FILE_VERSION_4;
+}
