@@ -59,12 +59,18 @@ void EditWidget::addPage(const QString& labelText, const QIcon& icon, QWidget* w
      * from automatic resizing and it now should be able to fit into a user's monitor even if the monitor is only 768
      * pixels high.
      */
-    auto* scrollArea = new QScrollArea(m_ui->stackedWidget);
-    scrollArea->setFrameShape(QFrame::NoFrame);
-    scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    scrollArea->setWidget(widget);
-    scrollArea->setWidgetResizable(true);
-    m_ui->stackedWidget->addWidget(scrollArea);
+    if (widget->inherits("QScrollArea")) {
+        m_ui->stackedWidget->addWidget(widget);
+    } else {
+        auto* scrollArea = new QScrollArea(m_ui->stackedWidget);
+        scrollArea->setFrameShape(QFrame::NoFrame);
+        scrollArea->setFrameShadow(QFrame::Plain);
+        scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+        scrollArea->setSizeAdjustPolicy(QScrollArea::AdjustToContents);
+        scrollArea->setWidgetResizable(true);
+        scrollArea->setWidget(widget);
+        m_ui->stackedWidget->addWidget(scrollArea);
+    }
     m_ui->categoryList->addCategory(labelText, icon);
 }
 
