@@ -1,5 +1,5 @@
 /* This file is part of the KDE libraries
- * 
+ *
  * Copyright (c) 2011 Aurélien Gâteau <agateau@kde.org>
  * Copyright (c) 2014 Dominik Haumann <dhaumann@kde.org>
  *
@@ -20,7 +20,7 @@
  */
 #include "KMessageWidget.h"
 
-#include "core/FilePath.h"
+#include "core/Resources.h"
 #include "core/Global.h"
 
 #include <QAction>
@@ -42,7 +42,7 @@ class KMessageWidgetPrivate
 {
 public:
     void init(KMessageWidget *);
-    
+
     KMessageWidget *q;
     QFrame *content;
     QLabel *iconLabel;
@@ -51,76 +51,70 @@ public:
     QTimeLine *timeLine;
     QIcon icon;
     QPixmap closeButtonPixmap;
-    
+
     KMessageWidget::MessageType messageType;
     bool wordWrap;
     QList<QToolButton *> buttons;
     QPixmap contentSnapShot;
-    
+
     void createLayout();
     void updateSnapShot();
     void updateLayout();
     void slotTimeLineChanged(qreal);
     void slotTimeLineFinished();
-    
+
     int bestContentHeight() const;
 };
 
 void KMessageWidgetPrivate::init(KMessageWidget *q_ptr)
 {
     q = q_ptr;
-    
+
     q->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
-    
+
     timeLine = new QTimeLine(500, q);
     QObject::connect(timeLine, SIGNAL(valueChanged(qreal)), q, SLOT(slotTimeLineChanged(qreal)));
     QObject::connect(timeLine, SIGNAL(finished()), q, SLOT(slotTimeLineFinished()));
-    
+
     content = new QFrame(q);
     content->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    
+
     wordWrap = false;
-    
+
     iconLabel = new QLabel(content);
     iconLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     iconLabel->hide();
-    
+
     textLabel = new QLabel(content);
     textLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     textLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     QObject::connect(textLabel, SIGNAL(linkActivated(QString)), q, SIGNAL(linkActivated(QString)));
     QObject::connect(textLabel, SIGNAL(linkHovered(QString)), q, SIGNAL(linkHovered(QString)));
-    
+
     QAction *closeAction = new QAction(q);
     closeAction->setText(KMessageWidget::tr("&Close"));
     closeAction->setToolTip(KMessageWidget::tr("Close message"));
-    closeAction->setIcon(FilePath::instance()->icon("actions", "message-close", false));
-    
+    closeAction->setIcon(Resources::instance()->icon("message-close"));
+
     QObject::connect(closeAction, SIGNAL(triggered(bool)), q, SLOT(animatedHide()));
 
     closeButton = new QToolButton(content);
     closeButton->setAutoRaise(true);
     closeButton->setDefaultAction(closeAction);
     closeButtonPixmap = QPixmap(closeButton->icon().pixmap(closeButton->icon().actualSize(QSize(16, 16))));
-#ifdef Q_OS_MACOS
-    closeButton->setStyleSheet("QToolButton { background: transparent;"
-                                   "border-radius: 2px; padding: 3px; }"
-                               "QToolButton::hover, QToolButton::focus {"
-                                   "border: 1px solid rgb(90, 200, 250); }");
-#endif
-    
+
     q->setMessageType(KMessageWidget::Information);
 }
 
 void KMessageWidgetPrivate::createLayout()
 {
     delete content->layout();
-    
+
     content->resize(q->size());
-    
+
     qDeleteAll(buttons);
     buttons.clear();
-    
+
     const auto actions = q->actions();
     for (QAction *action: actions) {
         QToolButton *button = new QToolButton(content);
@@ -128,18 +122,18 @@ void KMessageWidgetPrivate::createLayout()
         button->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
         buttons.append(button);
     }
-    
+
     // AutoRaise reduces visual clutter, but we don't want to turn it on if
     // there are other buttons, otherwise the close button will look different
     // from the others.
     closeButton->setAutoRaise(buttons.isEmpty());
-    
+
     if (wordWrap) {
         QGridLayout *layout = new QGridLayout(content);
         // Set alignment to make sure icon does not move down if text wraps
         layout->addWidget(iconLabel, 0, 0, 1, 1, Qt::AlignHCenter | Qt::AlignTop);
         layout->addWidget(textLabel, 0, 1);
-        
+
         QHBoxLayout *buttonLayout = new QHBoxLayout;
         buttonLayout->addStretch();
         for (QToolButton* button: asConst(buttons)) {
@@ -155,14 +149,14 @@ void KMessageWidgetPrivate::createLayout()
         QHBoxLayout *layout = new QHBoxLayout(content);
         layout->addWidget(iconLabel);
         layout->addWidget(textLabel);
-        
+
         for (QToolButton* button: asConst(buttons)) {
             layout->addWidget(button);
         }
-        
+
         layout->addWidget(closeButton);
     };
-    
+
     if (q->isVisible()) {
         q->setFixedHeight(content->sizeHint().height());
     }
@@ -201,7 +195,7 @@ void KMessageWidgetPrivate::slotTimeLineFinished()
         // We set the whole geometry here, because it may be wrong if a
         // KMessageWidget is shown right when the toplevel window is created.
         content->setGeometry(0, 0, q->width(), bestContentHeight());
-        
+
         // notify about finished animation
         emit q->showAnimationFinished();
     } else {
@@ -263,7 +257,7 @@ void KMessageWidget::setMessageType(KMessageWidget::MessageType type)
 {
     d->messageType = type;
     QColor bg0, bg1, bg2, border;
-    QColor fg = palette().light().color();
+    QColor fg = QColor(238, 238, 238);
     switch (type) {
     case Positive:
         bg1.setRgb(37, 163, 83);
@@ -273,7 +267,7 @@ void KMessageWidget::setMessageType(KMessageWidget::MessageType type)
         break;
     case Warning:
         bg1.setRgb(252, 193, 57);
-        fg = palette().foreground().color();
+        fg = QColor(48, 48, 48);
         break;
     case Error:
         bg1.setRgb(198, 69, 21);
@@ -294,9 +288,15 @@ void KMessageWidget::setMessageType(KMessageWidget::MessageType type)
     painter.fillRect(QRect(0, 0, 16, 16), fg);
     painter.end();
     d->closeButton->setIcon(closeButtonPixmap);
-    
+    d->closeButton->setStyleSheet(QStringLiteral("QToolButton {"
+                                  "  background: transparent;"
+                                  "  border-radius: 2px;"
+                                  "  border: none; }"
+                                  "QToolButton:hover, QToolButton:focus {"
+                                  "  border: 1px solid %1; }").arg(fg.name()));
+
     d->content->setStyleSheet(
-        QString(QLatin1String(".QFrame {"
+        QStringLiteral(".QFrame {"
         "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
         "    stop: 0 %1,"
         "    stop: 0.1 %2,"
@@ -307,7 +307,7 @@ void KMessageWidget::setMessageType(KMessageWidget::MessageType type)
         "    padding: 5px;"
         "}"
         ".QLabel { color: %6; }"
-        ))
+        )
         .arg(bg0.name(),
              bg1.name(),
              bg2.name(),
@@ -342,7 +342,7 @@ bool KMessageWidget::event(QEvent *event)
 void KMessageWidget::resizeEvent(QResizeEvent *event)
 {
     QFrame::resizeEvent(event);
-    
+
     if (d->timeLine->state() == QTimeLine::NotRunning) {
         d->content->resize(width(), d->bestContentHeight());
     }
@@ -415,18 +415,18 @@ void KMessageWidget::animatedShow()
         emit showAnimationFinished();
         return;
     }
-    
+
     if (isVisible()) {
         return;
     }
-    
+
     QFrame::show();
     setFixedHeight(0);
     int wantedHeight = d->bestContentHeight();
     d->content->setGeometry(0, -wantedHeight, width(), wantedHeight);
-    
+
     d->updateSnapShot();
-    
+
     d->timeLine->setDirection(QTimeLine::Forward);
     if (d->timeLine->state() == QTimeLine::NotRunning) {
         d->timeLine->start();
@@ -440,15 +440,15 @@ void KMessageWidget::animatedHide()
         emit hideAnimationFinished();
         return;
     }
-    
+
     if (!isVisible()) {
         hide();
         return;
     }
-    
+
     d->content->move(0, -d->content->height());
     d->updateSnapShot();
-    
+
     d->timeLine->setDirection(QTimeLine::Backward);
     if (d->timeLine->state() == QTimeLine::NotRunning) {
         d->timeLine->start();
