@@ -20,6 +20,8 @@
 
 #include "DatabaseSettingsWidget.h"
 
+#include "crypto/kdf/Kdf.h"
+
 #include <QPointer>
 #include <QScopedPointer>
 
@@ -49,11 +51,13 @@ public slots:
     void uninitialize() override;
     bool save() override;
 
+    static QString getTextualEncryptionTime(int millisecs);
+
 protected:
     void showEvent(QShowEvent* event) override;
 
 private slots:
-    void benchmarkTransformRounds(int millisecs = 1000);
+    void benchmarkTransformRounds(int millisecs = Kdf::DEFAULT_ENCRYPTION_TIME);
     void changeKdf(int index);
     void memoryChanged(int value);
     void parallelismChanged(int value);
