@@ -19,10 +19,11 @@
 #ifndef AGENTSETTINGSWIDGET_H
 #define AGENTSETTINGSWIDGET_H
 
-#include <QWidget>
 #include <QScopedPointer>
+#include <QWidget>
 
-namespace Ui {
+namespace Ui
+{
     class AgentSettingsWidget;
 }
 
@@ -36,6 +37,7 @@ public:
 public slots:
     void loadSettings();
     void saveSettings();
+    void toggleSettingsEnabled();
 
 private:
     QScopedPointer<Ui::AgentSettingsWidget> m_ui;
