@@ -71,7 +71,7 @@ public:
     ~QtIOCompressorPrivate();
     void flushZlib(int flushMode);
     bool writeBytes(ZlibByte *buffer, ZlibSize outputSize);
-    void setZlibError(const QString &erroMessage, int zlibErrorCode);
+    void setZlibError(const QString &errorMessage, int zlibErrorCode);
 
     QIODevice *device;
     bool manageDevice;
@@ -116,7 +116,7 @@ QtIOCompressorPrivate::~QtIOCompressorPrivate()
 void QtIOCompressorPrivate::flushZlib(int flushMode)
 {
     // No input.
-    zlibStream.next_in = 0;
+    zlibStream.next_in = nullptr;
     zlibStream.avail_in = 0;
     int status;
     do {
@@ -387,7 +387,7 @@ bool QtIOCompressor::open(OpenMode mode)
     if (read) {
         d->state = QtIOCompressorPrivate::NotReadFirstByte;
         d->zlibStream.avail_in = 0;
-        d->zlibStream.next_in = 0;
+        d->zlibStream.next_in = nullptr;
         if (d->streamFormat == QtIOCompressor::ZlibFormat) {
             status = inflateInit(&d->zlibStream);
         } else {
