@@ -27,6 +27,9 @@ class TestDatabase : public QObject
 
 private slots:
     void initTestCase();
+    void testOpen();
+    void testSave();
+    void testSignals();
     void testEmptyRecycleBinOnDisabled();
     void testEmptyRecycleBinOnNotCreated();
     void testEmptyRecycleBinOnEmpty();
