@@ -37,6 +37,8 @@ private slots:
     void testResolveReferencePlaceholders();
     void testResolveNonIdPlaceholdersToUuid();
     void testResolveClonedEntry();
+    void testIsRecycled();
+    void testMove();
 };
 
 #endif // KEEPASSX_TESTENTRY_H
